@@ -1,22 +1,8 @@
 /*
-    Copyright 2013, 2014 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2013-2015 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013, 2014 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2013-2015 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "modemdevice.h"
@@ -27,25 +13,25 @@
 #else
 #include "dbus/dbus.h"
 #endif
-#include "generictypes.h"
 #include "manager.h"
 #include "mmdebug_p.h"
-#include "modem.h"
-#include "modemcdma.h"
 #include "modem3gpp.h"
 #include "modem3gppussd.h"
+#include "modemcdma.h"
 #include "modemlocation.h"
 #if MM_CHECK_VERSION(1, 2, 0)
 #include "modemoma.h"
 #include "modemsignal.h"
 #endif
+#if MM_CHECK_VERSION(1, 6, 0)
+#include "modemvoice.h"
+#endif
+#include "modemfirmware.h"
 #include "modemsimple.h"
 #include "modemtime.h"
-#include "modemfirmware.h"
 
 #include <QDomDocument>
 
-
 ModemManager::ModemDevicePrivate::ModemDevicePrivate(const QString &path, ModemManager::ModemDevice *q)
     : uni(path)
     , q_ptr(q)
@@ -61,15 +47,31 @@ void ModemManager::ModemDevicePrivate::init()
 {
     Q_Q(ModemManager::ModemDevice);
 #ifdef MMQT_STATIC
-    QDBusConnection::sessionBus().connect(QLatin1String(MMQT_DBUS_SERVICE), QLatin1String(MMQT_DBUS_PATH), QLatin1String(DBUS_INTERFACE_MANAGER), QStringLiteral("InterfacesAdded"),
-                                         q, SLOT(onInterfacesAdded(QDBusObjectPath,MMVariantMapMap)));
-    QDBusConnection::sessionBus().connect(QLatin1String(MMQT_DBUS_SERVICE), QLatin1String(MMQT_DBUS_PATH), QLatin1String(DBUS_INTERFACE_MANAGER), QStringLiteral("InterfacesRemoved"),
-                                         q, SLOT(onInterfacesRemoved(QDBusObjectPath,QStringList)));
+    QDBusConnection::sessionBus().connect(QLatin1String(MMQT_DBUS_SERVICE),
+                                          QLatin1String(MMQT_DBUS_PATH),
+                                          QLatin1String(DBUS_INTERFACE_MANAGER),
+                                          QStringLiteral("InterfacesAdded"),
+                                          this,
+                                          SLOT(onInterfacesAdded(QDBusObjectPath, ModemManager::MMVariantMapMap)));
+    QDBusConnection::sessionBus().connect(QLatin1String(MMQT_DBUS_SERVICE),
+                                          QLatin1String(MMQT_DBUS_PATH),
+                                          QLatin1String(DBUS_INTERFACE_MANAGER),
+                                          QStringLiteral("InterfacesRemoved"),
+                                          this,
+                                          SLOT(onInterfacesRemoved(QDBusObjectPath, QStringList)));
 #else
-    QDBusConnection::systemBus().connect(QLatin1String(MMQT_DBUS_SERVICE), QLatin1String(MMQT_DBUS_PATH), QLatin1String(DBUS_INTERFACE_MANAGER), QStringLiteral("InterfacesAdded"),
-                                         q, SLOT(onInterfacesAdded(QDBusObjectPath,MMVariantMapMap)));
-    QDBusConnection::systemBus().connect(QLatin1String(MMQT_DBUS_SERVICE), QLatin1String(MMQT_DBUS_PATH), QLatin1String(DBUS_INTERFACE_MANAGER), QStringLiteral("InterfacesRemoved"),
-                                         q, SLOT(onInterfacesRemoved(QDBusObjectPath,QStringList)));
+    QDBusConnection::systemBus().connect(QLatin1String(MMQT_DBUS_SERVICE),
+                                         QLatin1String(MMQT_DBUS_PATH),
+                                         QLatin1String(DBUS_INTERFACE_MANAGER),
+                                         QStringLiteral("InterfacesAdded"),
+                                         this,
+                                         SLOT(onInterfacesAdded(QDBusObjectPath, ModemManager::MMVariantMapMap)));
+    QDBusConnection::systemBus().connect(QLatin1String(MMQT_DBUS_SERVICE),
+                                         QLatin1String(MMQT_DBUS_PATH),
+                                         QLatin1String(DBUS_INTERFACE_MANAGER),
+                                         QStringLiteral("InterfacesRemoved"),
+                                         this,
+                                         SLOT(onInterfacesRemoved(QDBusObjectPath, QStringList)));
 #endif
 
     initInterfaces();
@@ -101,10 +103,9 @@ void ModemManager::ModemDevicePrivate::initInterfaces()
                     ModemManager::Modem::Ptr modemInterface = interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                     if (!modemInterface->simPath().isEmpty()) {
                         simCard = ModemManager::Sim::Ptr(new ModemManager::Sim(modemInterface->simPath()), &QObject::deleteLater);
-                        //q->simAdded(modemInterface->simPath());
+                        // q->simAdded(modemInterface->simPath());
 
-                        QObject::connect(modemInterface.data(), SIGNAL(simPathChanged(QString,QString)),
-                                         this, SLOT(onSimPathChanged(QString,QString)));
+                        QObject::connect(modemInterface.data(), SIGNAL(simPathChanged(QString, QString)), this, SLOT(onSimPathChanged(QString, QString)));
                     }
                 }
             } else if (name == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_SIMPLE)) {
@@ -123,7 +124,7 @@ void ModemManager::ModemDevicePrivate::initInterfaces()
                 interfaceList.insert(ModemManager::ModemDevice::TimeInterface, ModemManager::ModemTime::Ptr());
             }
 #if MM_CHECK_VERSION(1, 2, 0)
-              else if (name == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_OMA)) {
+            else if (name == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_OMA)) {
                 interfaceList.insert(ModemManager::ModemDevice::OmaInterface, ModemManager::ModemOma::Ptr());
             } else if (name == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_SIGNAL)) {
                 interfaceList.insert(ModemManager::ModemDevice::SignalInterface, ModemManager::ModemSignal::Ptr());
@@ -132,6 +133,11 @@ void ModemManager::ModemDevicePrivate::initInterfaces()
             else if (name == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_FIRMWARE)) {
                 interfaceList.insert(ModemManager::ModemDevice::FirmwareInterface, ModemManager::ModemFirmware::Ptr());
             }
+#if MM_CHECK_VERSION(1, 6, 0)
+            else if (name == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_VOICE)) {
+                interfaceList.insert(ModemManager::ModemDevice::VoiceInterface, ModemManager::ModemVoice::Ptr());
+            }
+#endif
         }
     }
 
@@ -140,16 +146,17 @@ void ModemManager::ModemDevicePrivate::initInterfaces()
 
 QString ModemManager::ModemDevicePrivate::introspect() const
 {
-    QDBusMessage call = QDBusMessage::createMethodCall(QLatin1String(MMQT_DBUS_SERVICE), uni, QLatin1String(DBUS_INTERFACE_INTROSPECT), QLatin1String("Introspect"));
+    QDBusMessage call =
+        QDBusMessage::createMethodCall(QLatin1String(MMQT_DBUS_SERVICE), uni, QLatin1String(DBUS_INTERFACE_INTROSPECT), QLatin1String("Introspect"));
 #ifdef MMQT_STATIC
     QDBusPendingReply<QString> reply = QDBusConnection::sessionBus().call(call);
 #else
     QDBusPendingReply<QString> reply = QDBusConnection::systemBus().call(call);
 #endif
 
-    if (reply.isValid())
+    if (reply.isValid()) {
         return reply.value();
-    else {
+    } else {
         return QString();
     }
 }
@@ -208,41 +215,46 @@ ModemManager::Interface::Ptr ModemManager::ModemDevicePrivate::createInterface(M
 {
     ModemManager::Interface::Ptr createdInterface;
     switch (type) {
-        case ModemManager::ModemDevice::ModemInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::Modem(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::SimpleInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemSimple(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::GsmInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::Modem3gpp(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::GsmUssdInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::Modem3gppUssd(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::CdmaInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemCdma(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::MessagingInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemMessaging(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::LocationInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemLocation(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::TimeInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemTime(uni), &QObject::deleteLater);
-            break;
+    case ModemManager::ModemDevice::ModemInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::Modem(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::SimpleInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemSimple(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::GsmInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::Modem3gpp(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::GsmUssdInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::Modem3gppUssd(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::CdmaInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemCdma(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::MessagingInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemMessaging(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::LocationInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemLocation(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::TimeInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemTime(uni), &QObject::deleteLater);
+        break;
 #if MM_CHECK_VERSION(1, 2, 0)
-        case ModemManager::ModemDevice::OmaInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemOma(uni), &QObject::deleteLater);
-            break;
-        case ModemManager::ModemDevice::SignalInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemSignal(uni), &QObject::deleteLater);
-            break;
+    case ModemManager::ModemDevice::OmaInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemOma(uni), &QObject::deleteLater);
+        break;
+    case ModemManager::ModemDevice::SignalInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemSignal(uni), &QObject::deleteLater);
+        break;
+#endif
+    case ModemManager::ModemDevice::FirmwareInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemFirmware(uni), &QObject::deleteLater);
+        break;
+#if MM_CHECK_VERSION(1, 6, 0)
+    case ModemManager::ModemDevice::VoiceInterface:
+        createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemVoice(uni), &QObject::deleteLater);
+        break;
 #endif
-        case ModemManager::ModemDevice::FirmwareInterface:
-            createdInterface = ModemManager::Interface::Ptr(new ModemManager::ModemFirmware(uni), &QObject::deleteLater);
-            break;
     }
     return createdInterface;
 }
@@ -250,7 +262,7 @@ ModemManager::Interface::Ptr ModemManager::ModemDevicePrivate::createInterface(M
 ModemManager::Bearer::Ptr ModemManager::ModemDevicePrivate::findBearer(const QString &uni)
 {
     ModemManager::Bearer::Ptr result;
-    Q_FOREACH (const ModemManager::Bearer::Ptr & bearer, bearers()) {
+    Q_FOREACH (const ModemManager::Bearer::Ptr &bearer, bearers()) {
         if (bearer->uni() == uni) {
             result = bearer;
             break;
@@ -288,14 +300,14 @@ ModemManager::Interface::Ptr ModemManager::ModemDevice::interface(ModemManager::
 {
     Q_D(const ModemDevice);
 
-    return const_cast<ModemDevicePrivate*>(d)->interface(type);
+    return const_cast<ModemDevicePrivate *>(d)->interface(type);
 }
 
 ModemManager::Interface::List ModemManager::ModemDevice::interfaces() const
 {
     Q_D(const ModemDevice);
 
-    return const_cast<ModemDevicePrivate*>(d)->interfaces();
+    return const_cast<ModemDevicePrivate *>(d)->interfaces();
 }
 
 ModemManager::ModemMessaging::Ptr ModemManager::ModemDevice::messagingInterface()
@@ -323,14 +335,14 @@ ModemManager::Bearer::List ModemManager::ModemDevice::bearers() const
 {
     Q_D(const ModemDevice);
 
-    return const_cast<ModemDevicePrivate*>(d)->bearers();
+    return const_cast<ModemDevicePrivate *>(d)->bearers();
 }
 
 ModemManager::Sim::Ptr ModemManager::ModemDevice::sim() const
 {
     Q_D(const ModemDevice);
 
-    return const_cast<ModemDevicePrivate*>(d)->sim();
+    return const_cast<ModemDevicePrivate *>(d)->sim();
 }
 
 bool ModemManager::ModemDevice::isGsmModem() const
@@ -345,40 +357,58 @@ bool ModemManager::ModemDevice::isCdmaModem() const
 
 void ModemManager::ModemDevicePrivate::onInterfacesAdded(const QDBusObjectPath &object_path, const MMVariantMapMap &interfaces_and_properties)
 {
+    Q_Q(ModemDevice);
     if (object_path.path() != uni) {
         return;
     }
 
-    Q_FOREACH (const QString & iface, interfaces_and_properties.keys()) {
+    Q_FOREACH (const QString &iface, interfaces_and_properties.keys()) {
         /* Don't store generic DBus interfaces */
         if (iface.startsWith(QLatin1String(MMQT_DBUS_SERVICE))) {
             if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM)) {
                 interfaceList.insert(ModemManager::ModemDevice::ModemInterface, ModemManager::Modem::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::ModemInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_SIMPLE)) {
                 interfaceList.insert(ModemManager::ModemDevice::SimpleInterface, ModemManager::ModemSimple::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::SimpleInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MODEM3GPP)) {
                 interfaceList.insert(ModemManager::ModemDevice::GsmInterface, ModemManager::Modem3gpp::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::GsmInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MODEM3GPP_USSD)) {
                 interfaceList.insert(ModemManager::ModemDevice::GsmUssdInterface, ModemManager::Modem3gppUssd::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::GsmUssdInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MODEMCDMA)) {
                 interfaceList.insert(ModemManager::ModemDevice::CdmaInterface, ModemManager::ModemCdma::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::CdmaInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MESSAGING)) {
                 interfaceList.insert(ModemManager::ModemDevice::MessagingInterface, ModemManager::ModemMessaging::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::MessagingInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_LOCATION)) {
                 interfaceList.insert(ModemManager::ModemDevice::LocationInterface, ModemManager::ModemLocation::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::LocationInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_TIME)) {
                 interfaceList.insert(ModemManager::ModemDevice::TimeInterface, ModemManager::ModemTime::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::TimeInterface);
             }
 #if MM_CHECK_VERSION(1, 2, 0)
-              else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_OMA)) {
+            else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_OMA)) {
                 interfaceList.insert(ModemManager::ModemDevice::OmaInterface, ModemManager::ModemOma::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::OmaInterface);
             } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_SIGNAL)) {
                 interfaceList.insert(ModemManager::ModemDevice::SignalInterface, ModemManager::ModemSignal::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::SignalInterface);
             }
 #endif
             else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_FIRMWARE)) {
                 interfaceList.insert(ModemManager::ModemDevice::FirmwareInterface, ModemManager::ModemFirmware::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::FirmwareInterface);
             }
+#if MM_CHECK_VERSION(1, 6, 0)
+            else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_VOICE)) {
+                interfaceList.insert(ModemManager::ModemDevice::VoiceInterface, ModemManager::ModemVoice::Ptr());
+                Q_EMIT q->interfaceAdded(ModemManager::ModemDevice::VoiceInterface);
+            }
+#endif
         }
     }
 }
@@ -397,34 +427,51 @@ void ModemManager::ModemDevicePrivate::onInterfacesRemoved(const QDBusObjectPath
         }
     }
 
-    Q_FOREACH (const QString & iface, interfaces) {
+    Q_FOREACH (const QString &iface, interfaces) {
         if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM)) {
             interfaceList.remove(ModemManager::ModemDevice::ModemInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::ModemInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_SIMPLE)) {
             interfaceList.remove(ModemManager::ModemDevice::SimpleInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::SimpleInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MODEM3GPP)) {
             interfaceList.remove(ModemManager::ModemDevice::GsmInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::GsmInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MODEM3GPP_USSD)) {
             interfaceList.remove(ModemManager::ModemDevice::GsmUssdInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::GsmUssdInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MODEMCDMA)) {
             interfaceList.remove(ModemManager::ModemDevice::CdmaInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::CdmaInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_MESSAGING)) {
             interfaceList.remove(ModemManager::ModemDevice::MessagingInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::MessagingInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_LOCATION)) {
             interfaceList.remove(ModemManager::ModemDevice::LocationInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::LocationInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_TIME)) {
             interfaceList.remove(ModemManager::ModemDevice::TimeInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::TimeInterface);
         }
 #if MM_CHECK_VERSION(1, 2, 0)
-          else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_OMA)) {
+        else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_OMA)) {
             interfaceList.remove(ModemManager::ModemDevice::OmaInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::OmaInterface);
         } else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_SIGNAL)) {
             interfaceList.remove(ModemManager::ModemDevice::SignalInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::SignalInterface);
         }
 #endif
-          else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_FIRMWARE)) {
+        else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_FIRMWARE)) {
             interfaceList.remove(ModemManager::ModemDevice::FirmwareInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::FirmwareInterface);
         }
+#if MM_CHECK_VERSION(1, 6, 0)
+        else if (iface == QLatin1String(MMQT_DBUS_INTERFACE_MODEM_VOICE)) {
+            interfaceList.remove(ModemManager::ModemDevice::VoiceInterface);
+            Q_EMIT q->interfaceRemoved(ModemManager::ModemDevice::VoiceInterface);
+        }
+#endif
     }
 }
 
